@@ -25,7 +25,7 @@
 
 #include "asterisk.h"
 
-ASTERISK_FILE_VERSION(__FILE__, "$Revision: 100138 $")
+ASTERISK_FILE_VERSION(__FILE__, "$Revision: 111442 $")
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -51,7 +51,7 @@ ASTERISK_FILE_VERSION(__FILE__, "$Revision: 100138 $")
 #if defined(SOLARIS)
 #include <sys/sockio.h>
 #include <net/if.h>
-#else
+#elif defined(HAVE_GETIFADDRS)
 #include <ifaddrs.h>
 #endif
 
@@ -88,6 +88,12 @@ struct my_ifreq {
 	struct sockaddr_in ifru_addr;
 };
 
+#if (!defined(SOLARIS) && !defined(HAVE_GETIFADDRS))
+static int get_local_address(struct in_addr *ourip)
+{
+	return -1;
+}
+#else
 static void score_address(const struct sockaddr_in *sin, struct in_addr *best_addr, int *best_score)
 {
 	const char *address;
@@ -179,7 +185,7 @@ static int get_local_address(struct in_addr *ourip)
 #if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__linux__) || defined(__Darwin__)
 		for (ifap = ifaphead; ifap; ifap = ifap->ifa_next) {
 
-			if (ifap->ifa_addr->sa_family == AF_INET) {
+			if (ifap->ifa_addr && ifap->ifa_addr->sa_family == AF_INET) {
 				sin = (const struct sockaddr_in *) ifap->ifa_addr;
 				score_address(sin, &best_addr, &best_score);
 				res = 0;
@@ -241,6 +247,8 @@ static int get_local_address(struct in_addr *ourip)
 		memcpy(ourip, &best_addr, sizeof(*ourip));
 	return res;
 }
+#endif /* HAVE_GETIFADDRS */
+
 /* Free HA structure */
 void ast_free_ha(struct ast_ha *ha)
 {
